@@ -1,4 +1,4 @@
-from fakeredis.stack import JSONCommandsMixin
+from fakeredis.stack import JSONCommandsMixin, BFCommandsMixin
 from ._basefakesocket import BaseFakeSocket
 from .commands_mixins.bitmap_mixin import BitmapCommandsMixin
 from .commands_mixins.connection_mixin import ConnectionCommandsMixin
@@ -33,7 +33,7 @@ class FakeSocket(
     StreamsCommandsMixin,
     JSONCommandsMixin,
     GeoCommandsMixin,
+    BFCommandsMixin,
 ):
-
     def __init__(self, server, db):
         super(FakeSocket, self).__init__(server, db)
