@@ -1,9 +1,18 @@
 import math
+from typing import Tuple, Callable
 
 from fakeredis import _msgs as msgs
 from fakeredis._command_args_parsing import extract_args
-from fakeredis._commands import (command, Key, Int, Float, MAX_STRING_SIZE, delete_keys, fix_range_string)
-from fakeredis._helpers import (OK, SimpleError, casematch)
+from fakeredis._commands import (
+    command,
+    Key,
+    Int,
+    Float,
+    MAX_STRING_SIZE,
+    delete_keys,
+    fix_range_string,
+)
+from fakeredis._helpers import OK, SimpleError, casematch, Database
 
 
 def _lcs(s1, s2):
@@ -33,7 +42,7 @@ def _lcs(s1, s2):
     # Algorithm to calculate the longest common subsequence using the Pi array
     # Also calculate the list of matches
     r, c = l1, l2
-    result = ''
+    result = ""
     matches = list()
     s1ind, s2ind, curr_length = None, None, 0
 
@@ -61,14 +70,17 @@ def _lcs(s1, s2):
 
 
 class StringCommandsMixin:
-    # String commands
+    _db: Database
+    version: Tuple[int]
+    _encodeint: Callable
+    _encodefloat: Callable
 
     @command((Key(bytes), bytes))
     def append(self, key, value):
-        old = key.get(b'')
+        old = key.get(b"")
         if len(old) + len(value) > MAX_STRING_SIZE:
             raise SimpleError(msgs.STRING_OVERFLOW_MSG)
-        key.update(key.get(b'') + value)
+        key.update(key.get(b"") + value)
         return len(key.value)
 
     @command((Key(bytes),))
@@ -89,9 +101,9 @@ class StringCommandsMixin:
         delete_keys(key)
         return res
 
-    @command(name=['GETRANGE', 'SUBSTR'], fixed=(Key(bytes), Int, Int))
+    @command(name=["GETRANGE", "SUBSTR"], fixed=(Key(bytes), Int, Int))
     def getrange(self, key, start, end):
-        value = key.get(b'')
+        value = key.get(b"")
         start, end = fix_range_string(start, end, len(value))
         return value[start:end]
 
@@ -103,7 +115,7 @@ class StringCommandsMixin:
 
     @command((Key(bytes), Int))
     def incrby(self, key, amount):
-        c = Int.decode(key.get(b'0')) + amount
+        c = Int.decode(key.get(b"0")) + amount
         key.update(self._encodeint(c))
         return c
 
@@ -114,7 +126,7 @@ class StringCommandsMixin:
     @command((Key(bytes), bytes))
     def incrbyfloat(self, key, amount):
         # TODO: introduce convert_order so that we can specify amount is Float
-        c = Float.decode(key.get(b'0')) + Float.decode(amount)
+        c = Float.decode(key.get(b"0")) + Float.decode(amount)
         if not math.isfinite(c):
             raise SimpleError(msgs.NONFINITE_MSG)
         encoded = self._encodefloat(c, True)
@@ -143,18 +155,20 @@ class StringCommandsMixin:
     @command((Key(), Int, bytes))
     def psetex(self, key, ms, value):
         if ms <= 0 or self._db.time * 1000 + ms >= 2 ** 63:
-            raise SimpleError(msgs.INVALID_EXPIRE_MSG.format('psetex'))
+            raise SimpleError(msgs.INVALID_EXPIRE_MSG.format("psetex"))
         key.value = value
         key.expireat = self._db.time + ms / 1000.0
         return OK
 
     @command(name="SET", fixed=(Key(), bytes), repeat=(bytes,))
     def set_(self, key, value, *args):
-        (ex, px, xx, nx, keepttl, get), _ = extract_args(args, ('+ex', '+px', 'xx', 'nx', 'keepttl', 'get'))
+        (ex, px, xx, nx, keepttl, get), _ = extract_args(
+            args, ("+ex", "+px", "xx", "nx", "keepttl", "get")
+        )
         if ex is not None and (ex <= 0 or (self._db.time + ex) * 1000 >= 2 ** 63):
-            raise SimpleError(msgs.INVALID_EXPIRE_MSG.format('set'))
+            raise SimpleError(msgs.INVALID_EXPIRE_MSG.format("set"))
         if px is not None and (px <= 0 or self._db.time * 1000 + px >= 2 ** 63):
-            raise SimpleError(msgs.INVALID_EXPIRE_MSG.format('set'))
+            raise SimpleError(msgs.INVALID_EXPIRE_MSG.format("set"))
 
         if (xx and nx) or ((px is not None) + (ex is not None) + keepttl > 1):
             raise SimpleError(msgs.SYNTAX_ERROR_MSG)
@@ -185,7 +199,7 @@ class StringCommandsMixin:
     @command((Key(), Int, bytes))
     def setex(self, key, seconds, value):
         if seconds <= 0 or (self._db.time + seconds) * 1000 >= 2 ** 63:
-            raise SimpleError(msgs.INVALID_EXPIRE_MSG.format('setex'))
+            raise SimpleError(msgs.INVALID_EXPIRE_MSG.format("setex"))
         key.value = value
         key.expireat = self._db.time + seconds
         return OK
@@ -202,19 +216,19 @@ class StringCommandsMixin:
         if offset < 0:
             raise SimpleError(msgs.INVALID_OFFSET_MSG)
         elif not value:
-            return len(key.get(b''))
+            return len(key.get(b""))
         elif offset + len(value) > MAX_STRING_SIZE:
             raise SimpleError(msgs.STRING_OVERFLOW_MSG)
-        out = key.get(b'')
+        out = key.get(b"")
         if len(out) < offset:
-            out += b'\x00' * (offset - len(out))
+            out += b"\x00" * (offset - len(out))
         out = out[0:offset] + value + out[offset + len(value):]
         key.update(out)
         return len(out)
 
     @command((Key(bytes),))
     def strlen(self, key):
-        return len(key.get(b''))
+        return len(key.get(b""))
 
     @command((Key(bytes),), (bytes,))
     def getex(self, key, *args):
@@ -222,41 +236,50 @@ class StringCommandsMixin:
 
         while i < len(args):
             count_options += 1
-            if casematch(args[i], b'ex') and i + 1 < len(args):
+            if casematch(args[i], b"ex") and i + 1 < len(args):
                 diff = Int.decode(args[i + 1])
                 expire_time = self._db.time + diff
                 i += 2
-            elif casematch(args[i], b'px') and i + 1 < len(args):
+            elif casematch(args[i], b"px") and i + 1 < len(args):
                 diff = Int.decode(args[i + 1])
                 expire_time = (self._db.time * 1000 + diff) / 1000.0
                 i += 2
-            elif casematch(args[i], b'exat') and i + 1 < len(args):
+            elif casematch(args[i], b"exat") and i + 1 < len(args):
                 expire_time = Int.decode(args[i + 1])
                 i += 2
-            elif casematch(args[i], b'pxat') and i + 1 < len(args):
+            elif casematch(args[i], b"pxat") and i + 1 < len(args):
                 expire_time = Int.decode(args[i + 1]) / 1000.0
                 i += 2
-            elif casematch(args[i], b'persist'):
+            elif casematch(args[i], b"persist"):
                 expire_time = None
                 i += 1
             else:
                 raise SimpleError(msgs.SYNTAX_ERROR_MSG)
-        if ((expire_time is not None and (expire_time <= 0 or expire_time * 1000 >= 2 ** 63))
-                or (diff is not None and (diff <= 0 or diff * 1000 >= 2 ** 63))):
-            raise SimpleError(msgs.INVALID_EXPIRE_MSG.format('getex'))
+        if (
+                expire_time is not None
+                and (expire_time <= 0 or expire_time * 1000 >= 2 ** 63)
+        ) or (diff is not None and (diff <= 0 or diff * 1000 >= 2 ** 63)):
+            raise SimpleError(msgs.INVALID_EXPIRE_MSG.format("getex"))
         if count_options > 1:
             raise SimpleError(msgs.SYNTAX_ERROR_MSG)
 
         key.expireat = expire_time
         return key.get(None)
 
-    @command((Key(bytes), Key(bytes),), (bytes,))
+    @command(
+        (
+                Key(bytes),
+                Key(bytes),
+        ),
+        (bytes,),
+    )
     def lcs(self, k1, k2, *args):
-        s1 = k1.value or b''
-        s2 = k2.value or b''
+        s1 = k1.value or b""
+        s2 = k2.value or b""
 
         (arg_idx, arg_len, arg_minmatchlen, arg_withmatchlen), _ = extract_args(
-            args, ('idx', 'len', '+minmatchlen', 'withmatchlen'))
+            args, ("idx", "len", "+minmatchlen", "withmatchlen")
+        )
         if arg_idx and arg_len:
             raise SimpleError(msgs.LCS_CANT_HAVE_BOTH_LEN_AND_IDX)
         lcs_len, lcs_val, matches = _lcs(s1, s2)
@@ -268,4 +291,4 @@ class StringCommandsMixin:
         results = list(filter(lambda x: x[2] >= arg_minmatchlen, matches))
         if not arg_withmatchlen:
             results = list(map(lambda x: [x[0], x[1]], results))
-        return [b'matches', results, b'len', lcs_len]
+        return [b"matches", results, b"len", lcs_len]
